# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class ConvertOfficeFormatRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ConvertOfficeFormat','imm')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SrcType(self):
		return self.get_query_params().get('SrcType')

	def set_SrcType(self,SrcType):
		self.add_query_param('SrcType',SrcType)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_PdfVector(self):
		return self.get_query_params().get('PdfVector')

	def set_PdfVector(self,PdfVector):
		self.add_query_param('PdfVector',PdfVector)

	def get_Password(self):
		return self.get_query_params().get('Password')

	def set_Password(self,Password):
		self.add_query_param('Password',Password)

	def get_StartPage(self):
		return self.get_query_params().get('StartPage')

	def set_StartPage(self,StartPage):
		self.add_query_param('StartPage',StartPage)

	def get_FitToPagesWide(self):
		return self.get_query_params().get('FitToPagesWide')

	def set_FitToPagesWide(self,FitToPagesWide):
		self.add_query_param('FitToPagesWide',FitToPagesWide)

	def get_TgtFilePrefix(self):
		return self.get_query_params().get('TgtFilePrefix')

	def set_TgtFilePrefix(self,TgtFilePrefix):
		self.add_query_param('TgtFilePrefix',TgtFilePrefix)

	def get_ModelId(self):
		return self.get_query_params().get('ModelId')

	def set_ModelId(self,ModelId):
		self.add_query_param('ModelId',ModelId)

	def get_MaxSheetRow(self):
		return self.get_query_params().get('MaxSheetRow')

	def set_MaxSheetRow(self,MaxSheetRow):
		self.add_query_param('MaxSheetRow',MaxSheetRow)

	def get_MaxSheetCount(self):
		return self.get_query_params().get('MaxSheetCount')

	def set_MaxSheetCount(self,MaxSheetCount):
		self.add_query_param('MaxSheetCount',MaxSheetCount)

	def get_EndPage(self):
		return self.get_query_params().get('EndPage')

	def set_EndPage(self,EndPage):
		self.add_query_param('EndPage',EndPage)

	def get_TgtFileSuffix(self):
		return self.get_query_params().get('TgtFileSuffix')

	def set_TgtFileSuffix(self,TgtFileSuffix):
		self.add_query_param('TgtFileSuffix',TgtFileSuffix)

	def get_SheetOnePage(self):
		return self.get_query_params().get('SheetOnePage')

	def set_SheetOnePage(self,SheetOnePage):
		self.add_query_param('SheetOnePage',SheetOnePage)

	def get_MaxSheetCol(self):
		return self.get_query_params().get('MaxSheetCol')

	def set_MaxSheetCol(self,MaxSheetCol):
		self.add_query_param('MaxSheetCol',MaxSheetCol)

	def get_TgtType(self):
		return self.get_query_params().get('TgtType')

	def set_TgtType(self,TgtType):
		self.add_query_param('TgtType',TgtType)

	def get_Hidecomments(self):
		return self.get_query_params().get('Hidecomments')

	def set_Hidecomments(self,Hidecomments):
		self.add_query_param('Hidecomments',Hidecomments)

	def get_FitToPagesTall(self):
		return self.get_query_params().get('FitToPagesTall')

	def set_FitToPagesTall(self,FitToPagesTall):
		self.add_query_param('FitToPagesTall',FitToPagesTall)

	def get_SrcUri(self):
		return self.get_query_params().get('SrcUri')

	def set_SrcUri(self,SrcUri):
		self.add_query_param('SrcUri',SrcUri)

	def get_TgtFilePages(self):
		return self.get_query_params().get('TgtFilePages')

	def set_TgtFilePages(self,TgtFilePages):
		self.add_query_param('TgtFilePages',TgtFilePages)

	def get_TgtUri(self):
		return self.get_query_params().get('TgtUri')

	def set_TgtUri(self,TgtUri):
		self.add_query_param('TgtUri',TgtUri)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class CreateCADConversionTaskRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'CreateCADConversionTask','imm')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SrcType(self):
		return self.get_query_params().get('SrcType')

	def set_SrcType(self,SrcType):
		self.add_query_param('SrcType',SrcType)

	def get_BaseRow(self):
		return self.get_query_params().get('BaseRow')

	def set_BaseRow(self,BaseRow):
		self.add_query_param('BaseRow',BaseRow)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_ZoomFactor(self):
		return self.get_query_params().get('ZoomFactor')

	def set_ZoomFactor(self,ZoomFactor):
		self.add_query_param('ZoomFactor',ZoomFactor)

	def get_NotifyEndpoint(self):
		return self.get_query_params().get('NotifyEndpoint')

	def set_NotifyEndpoint(self,NotifyEndpoint):
		self.add_query_param('NotifyEndpoint',NotifyEndpoint)

	def get_BaseCol(self):
		return self.get_query_params().get('BaseCol')

	def set_BaseCol(self,BaseCol):
		self.add_query_param('BaseCol',BaseCol)

	def get_NotifyTopicName(self):
		return self.get_query_params().get('NotifyTopicName')

	def set_NotifyTopicName(self,NotifyTopicName):
		self.add_query_param('NotifyTopicName',NotifyTopicName)

	def get_UnitWidth(self):
		return self.get_query_params().get('UnitWidth')

	def set_UnitWidth(self,UnitWidth):
		self.add_query_param('UnitWidth',UnitWidth)

	def get_ZoomLevel(self):
		return self.get_query_params().get('ZoomLevel')

	def set_ZoomLevel(self,ZoomLevel):
		self.add_query_param('ZoomLevel',ZoomLevel)

	def get_ModelId(self):
		return self.get_query_params().get('ModelId')

	def set_ModelId(self,ModelId):
		self.add_query_param('ModelId',ModelId)

	def get_TgtType(self):
		return self.get_query_params().get('TgtType')

	def set_TgtType(self,TgtType):
		self.add_query_param('TgtType',TgtType)

	def get_UnitHeight(self):
		return self.get_query_params().get('UnitHeight')

	def set_UnitHeight(self,UnitHeight):
		self.add_query_param('UnitHeight',UnitHeight)

	def get_SrcUri(self):
		return self.get_query_params().get('SrcUri')

	def set_SrcUri(self,SrcUri):
		self.add_query_param('SrcUri',SrcUri)

	def get_Thumbnails(self):
		return self.get_query_params().get('Thumbnails')

	def set_Thumbnails(self,Thumbnails):
		self.add_query_param('Thumbnails',Thumbnails)

	def get_TgtUri(self):
		return self.get_query_params().get('TgtUri')

	def set_TgtUri(self,TgtUri):
		self.add_query_param('TgtUri',TgtUri)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class IndexVideoRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'IndexVideo','imm')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_ExternalId(self):
		return self.get_query_params().get('ExternalId')

	def set_ExternalId(self,ExternalId):
		self.add_query_param('ExternalId',ExternalId)

	def get_NotifyEndpoint(self):
		return self.get_query_params().get('NotifyEndpoint')

	def set_NotifyEndpoint(self,NotifyEndpoint):
		self.add_query_param('NotifyEndpoint',NotifyEndpoint)

	def get_NotifyTopicName(self):
		return self.get_query_params().get('NotifyTopicName')

	def set_NotifyTopicName(self,NotifyTopicName):
		self.add_query_param('NotifyTopicName',NotifyTopicName)

	def get_RemarksB(self):
		return self.get_query_params().get('RemarksB')

	def set_RemarksB(self,RemarksB):
		self.add_query_param('RemarksB',RemarksB)

	def get_RemarksA(self):
		return self.get_query_params().get('RemarksA')

	def set_RemarksA(self,RemarksA):
		self.add_query_param('RemarksA',RemarksA)

	def get_VideoUri(self):
		return self.get_query_params().get('VideoUri')

	def set_VideoUri(self,VideoUri):
		self.add_query_param('VideoUri',VideoUri)

	def get_RemarksD(self):
		return self.get_query_params().get('RemarksD')

	def set_RemarksD(self,RemarksD):
		self.add_query_param('RemarksD',RemarksD)

	def get_RemarksC(self):
		return self.get_query_params().get('RemarksC')

	def set_RemarksC(self,RemarksC):
		self.add_query_param('RemarksC',RemarksC)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

	def get_TgtUri(self):
		return self.get_query_params().get('TgtUri')

	def set_TgtUri(self,TgtUri):
		self.add_query_param('TgtUri',TgtUri)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class FindImagesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'FindImages','imm')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_RemarksArrayBIn(self):
		return self.get_query_params().get('RemarksArrayBIn')

	def set_RemarksArrayBIn(self,RemarksArrayBIn):
		self.add_query_param('RemarksArrayBIn',RemarksArrayBIn)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_ExternalId(self):
		return self.get_query_params().get('ExternalId')

	def set_ExternalId(self,ExternalId):
		self.add_query_param('ExternalId',ExternalId)

	def get_FacesModifyTimeRange(self):
		return self.get_query_params().get('FacesModifyTimeRange')

	def set_FacesModifyTimeRange(self,FacesModifyTimeRange):
		self.add_query_param('FacesModifyTimeRange',FacesModifyTimeRange)

	def get_OCRContentsMatch(self):
		return self.get_query_params().get('OCRContentsMatch')

	def set_OCRContentsMatch(self,OCRContentsMatch):
		self.add_query_param('OCRContentsMatch',OCRContentsMatch)

	def get_Limit(self):
		return self.get_query_params().get('Limit')

	def set_Limit(self,Limit):
		self.add_query_param('Limit',Limit)

	def get_RemarksDPrefix(self):
		return self.get_query_params().get('RemarksDPrefix')

	def set_RemarksDPrefix(self,RemarksDPrefix):
		self.add_query_param('RemarksDPrefix',RemarksDPrefix)

	def get_SourceType(self):
		return self.get_query_params().get('SourceType')

	def set_SourceType(self,SourceType):
		self.add_query_param('SourceType',SourceType)

	def get_Order(self):
		return self.get_query_params().get('Order')

	def set_Order(self,Order):
		self.add_query_param('Order',Order)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_OrderBy(self):
		return self.get_query_params().get('OrderBy')

	def set_OrderBy(self,OrderBy):
		self.add_query_param('OrderBy',OrderBy)

	def get_TagNames(self):
		return self.get_query_params().get('TagNames')

	def set_TagNames(self,TagNames):
		self.add_query_param('TagNames',TagNames)

	def get_Marker(self):
		return self.get_query_params().get('Marker')

	def set_Marker(self,Marker):
		self.add_query_param('Marker',Marker)

	def get_RemarksCPrefix(self):
		return self.get_query_params().get('RemarksCPrefix')

	def set_RemarksCPrefix(self,RemarksCPrefix):
		self.add_query_param('RemarksCPrefix',RemarksCPrefix)

	def get_ModifyTimeRange(self):
		return self.get_query_params().get('ModifyTimeRange')

	def set_ModifyTimeRange(self,ModifyTimeRange):
		self.add_query_param('ModifyTimeRange',ModifyTimeRange)

	def get_AddressLineContentsMatch(self):
		return self.get_query_params().get('AddressLineContentsMatch')

	def set_AddressLineContentsMatch(self,AddressLineContentsMatch):
		self.add_query_param('AddressLineContentsMatch',AddressLineContentsMatch)

	def get_Gender(self):
		return self.get_query_params().get('Gender')

	def set_Gender(self,Gender):
		self.add_query_param('Gender',Gender)

	def get_RemarksArrayAIn(self):
		return self.get_query_params().get('RemarksArrayAIn')

	def set_RemarksArrayAIn(self,RemarksArrayAIn):
		self.add_query_param('RemarksArrayAIn',RemarksArrayAIn)

	def get_ImageSizeRange(self):
		return self.get_query_params().get('ImageSizeRange')

	def set_ImageSizeRange(self,ImageSizeRange):
		self.add_query_param('ImageSizeRange',ImageSizeRange)

	def get_RemarksBPrefix(self):
		return self.get_query_params().get('RemarksBPrefix')

	def set_RemarksBPrefix(self,RemarksBPrefix):
		self.add_query_param('RemarksBPrefix',RemarksBPrefix)

	def get_LocationBoundary(self):
		return self.get_query_params().get('LocationBoundary')

	def set_LocationBoundary(self,LocationBoundary):
		self.add_query_param('LocationBoundary',LocationBoundary)

	def get_ImageTimeRange(self):
		return self.get_query_params().get('ImageTimeRange')

	def set_ImageTimeRange(self,ImageTimeRange):
		self.add_query_param('ImageTimeRange',ImageTimeRange)

	def get_TagsModifyTimeRange(self):
		return self.get_query_params().get('TagsModifyTimeRange')

	def set_TagsModifyTimeRange(self,TagsModifyTimeRange):
		self.add_query_param('TagsModifyTimeRange',TagsModifyTimeRange)

	def get_AgeRange(self):
		return self.get_query_params().get('AgeRange')

	def set_AgeRange(self,AgeRange):
		self.add_query_param('AgeRange',AgeRange)

	def get_RemarksAPrefix(self):
		return self.get_query_params().get('RemarksAPrefix')

	def set_RemarksAPrefix(self,RemarksAPrefix):
		self.add_query_param('RemarksAPrefix',RemarksAPrefix)

	def get_SourceUriPrefix(self):
		return self.get_query_params().get('SourceUriPrefix')

	def set_SourceUriPrefix(self,SourceUriPrefix):
		self.add_query_param('SourceUriPrefix',SourceUriPrefix)

	def get_Emotion(self):
		return self.get_query_params().get('Emotion')

	def set_Emotion(self,Emotion):
		self.add_query_param('Emotion',Emotion)

	def get_CreateTimeRange(self):
		return self.get_query_params().get('CreateTimeRange')

	def set_CreateTimeRange(self,CreateTimeRange):
		self.add_query_param('CreateTimeRange',CreateTimeRange)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)